3D Hasegawa-Wakatani model
==========================

Adds a simple Ohm's law to the 2D Hasegawa-Wakatani model,
so that second derivatives along the magnetic field appear in the model.
A 3D grid is then used to evolve drift-wave turbulence.


